@@ -1,5 +1,4 @@
 from contextlib import suppress
-import collections
 import curses
 
 import visidata
@@ -60,7 +59,7 @@ def until_get_wch(scr):
     return ret
 
 
-def splice(v, i, s):
+def splice(v:str, i:int, s:str):
     'Insert `s` into string `v` at `i` (such that v[i] == s[0]).'
     return v if i < 0 else v[:i] + s + v[i:]
 
@@ -223,11 +222,11 @@ def editline(vd, scr, y, x, w, i=0, attr=curses.A_NORMAL, value='', fillchar=' '
         elif ch == '^K':                           v = v[:i]  # ^Kill to end-of-line
         elif ch == '^O':                           v = vd.launchExternalEditor(v)
         elif ch == '^R':                           v = str(value)  # ^Reload initial value
-        elif ch == '^T':                           v = delchar(splice(v, i-2, v[i-1]), i)  # swap chars
+        elif ch == '^T':                           v = delchar(splice(v, i-2, v[i-1:i]), i)  # swap chars
         elif ch == '^U':                           v = v[i:]; i = 0  # clear to beginning
         elif ch == '^V':                           v = splice(v, i, until_get_wch(scr)); i += 1  # literal character
         elif ch == '^W':                           j = find_nonword(v, 0, i-1, -1); v = v[:j+1] + v[i:]; i = j+1  # erase word
-        elif ch == '^Y':                           v = splice(v, i, vd.memory.clipval)
+        elif ch == '^Y':                           v = splice(v, i, str(vd.memory.clipval))
         elif ch == '^Z':                           suspend()
         # CTRL+arrow
         elif ch == 'kLFT5':                        i = find_nonword(v, 0, i-1, -1)+1; # word left
@@ -301,7 +300,9 @@ def inputsingle(vd, prompt, record=True):
     rstatuslen = vd.drawRightStatus(sheet._scr, sheet)
     promptlen = clipdraw(sheet._scr, y, 0, prompt, 0, w=w-rstatuslen-1)
     sheet._scr.move(y, w-promptlen-rstatuslen-2)
-    v = vd.getkeystroke(sheet._scr)
+
+    while not v:
+        v = vd.getkeystroke(sheet._scr)
 
     if record and vd.cmdlog:
         vd.setLastArgs(v)
