@@ -5,9 +5,10 @@ import itertools
 import threading
 import re
 import time
+import json
 
 from visidata import options, anytype, stacktrace, vd
-from visidata import asyncthread, dispwidth
+from visidata import asyncthread, dispwidth, clipstr, iterchars
 from visidata import wrapply, TypedWrapper, TypedExceptionWrapper
 from visidata import Extensible, AttrDict, undoAttrFunc
 
@@ -101,6 +102,8 @@ class Column(Extensible):
         self.height = 1       # max height, None/0 to auto-compute for each row
         self.keycol = 0       # keycol index (or 0 if not key column)
         self.expr = None      # Column-type-dependent parameter
+        self.formatter = ''
+        self.defer = False
 
         self.setCache(cache)
         for k, v in kwargs.items():
@@ -119,7 +122,7 @@ class Column(Extensible):
         return self.__copy__()  # no separate deepcopy
 
     def __getstate__(self):
-        d = {k:getattr(self, k) for k in 'name width height expr keycol fmtstr voffset hoffset aggstr'.split()}
+        d = {k:getattr(self, k) for k in 'name width height expr keycol formatter fmtstr voffset hoffset aggstr'.split() if hasattr(self, k)}
         d['type'] = self.type.__name__
         return d
 
@@ -191,6 +194,12 @@ class Column(Extensible):
                 vd.addUndo(setattr, self, '_width', self.width)
             self._width = w
 
+    @property
+    def _formatdict(col):
+        if '=' in col.fmtstr:
+            return dict(val.split('=', maxsplit=1) for val in col.fmtstr.split())
+        return {}
+
     @property
     def fmtstr(self):
         'Format string to use to display this column.'
@@ -200,22 +209,48 @@ class Column(Extensible):
     def fmtstr(self, v):
         self._fmtstr = v
 
-    def formatValue(self, typedval):
+    def _format_len(self, typedval, **kwargs):
+        if isinstance(typedval, dict):
+            return f'{{{len(typedval)}}}'
+        elif isinstance(typedval, (list, tuple)):
+            return f'[{len(typedval)}]'
+
+        return self.formatValue(typedval, **kwargs)
+
+    def formatter_len(self, fmtstr):
+        return self._format_len
+
+    def formatter_generic(self, fmtstr):
+        return self.formatValue
+
+    def formatter_json(self, fmtstr):
+        return lambda v,*args,**kwargs: json.dumps(v)
+
+    def formatter_python(self, fmtstr):
+        return lambda v,*args,**kwargs: str(v)
+
+    def make_formatter(self):
+        'Return function for format(v) from the current formatter and fmtstr'
+        _formatMaker = getattr(self, 'formatter_'+(self.formatter or self.sheet.options.disp_formatter))
+        return _formatMaker(self._formatdict)
+
+    def format(self, *args, **kwargs):
+        return self.make_formatter()(*args, **kwargs)
+
+    def formatValue(self, typedval, width=None):
         'Return displayable string of *typedval* according to ``Column.fmtstr``.'
         if typedval is None:
             return None
 
         if self.type is anytype:
-            if isinstance(typedval, (list, tuple)):
-                return '[%s]' % len(typedval)
-            if isinstance(typedval, dict):
-                return '{%s}' % len(typedval)
+            if isinstance(typedval, (dict, list, tuple)):
+                dispval, dispw = clipstr(iterchars(typedval), width)
+                return dispval
 
         if isinstance(typedval, bytes):
             typedval = typedval.decode(options.encoding, options.encoding_errors)
 
         return vd.getType(self.type).formatter(self.fmtstr, typedval)
-    format=formatValue
 
     def hide(self, hide=True):
         if hide:
@@ -262,7 +297,7 @@ class Column(Extensible):
     def getValue(self, row):
         'Return value for *row* in this column, calculating if not cached.'
 
-        if self.sheet.defer:
+        if self.defer:
             try:
                 row, rowmods = self.sheet._deferredMods[self.sheet.rowid(row)]
                 return rowmods[self]
@@ -327,7 +362,7 @@ class Column(Extensible):
         dw = DisplayWrapper(cellval)
 
         try:
-            dw.display = self.format(typedval) or ''
+            dw.display = self.format(typedval, width=(self.width or 0)*2) or ''
 
             # annotate cells with raw value type in anytype columns, except for strings
             if self.type is anytype and type(cellval) is not str:
@@ -353,16 +388,17 @@ class Column(Extensible):
         return self.getCell(row).display
 
     def putValue(self, row, val):
-        'Change value for *row* in this column to *val* immediately.  Does not check the type.  Overrideable; by default calls ``.setter(row, val)``.'
+        'Change value for *row* in this column to *val* immediately.  Does not check the type.  Overridable; by default calls ``.setter(row, val)``.'
         return self.setter(self, row, val)
 
-    def setValue(self, row, val):
-        'Change value for *row* in this column to *val*.  Call ``putValue`` immediately if parent ``sheet.defer`` is False, otherwise cache until later ``putChanges``.  Caller must add undo function.'
-        if self.sheet.defer:
+    def setValue(self, row, val, setModified=True):
+        'Change value for *row* in this column to *val*.  Call ``putValue`` immediately if not a deferred column (added to deferred parent at load-time); otherwise cache until later ``putChanges``.  Caller must add undo function.'
+        if self.defer:
             self.cellChanged(row, val)
         else:
             self.putValue(row, val)
-        self.sheet.setModified()
+        if setModified:  #1800
+            self.sheet.setModified()
 
     def setValueSafe(self, row, value):
         'setValue and ignore exceptions.'
@@ -395,8 +431,18 @@ class Column(Extensible):
         w = 0
         nlen = dispwidth(self.name)
         if len(rows) > 0:
-            w = max(max(dispwidth(self.getDisplayValue(r), maxwidth=self.sheet.windowWidth) for r in rows), nlen)+2
-        return max(w, nlen)
+            w_max = 0
+            for r in rows:
+                row_w = dispwidth(self.getDisplayValue(r), maxwidth=self.sheet.windowWidth)
+                if w_max < row_w:
+                    w_max = row_w
+                if w_max >= self.sheet.windowWidth:
+                    break
+            w = w_max
+        w = max(w, nlen)+2
+        w = min(w, self.sheet.windowWidth)
+        return w
+
 
 
 # ---- Column makers
@@ -444,7 +490,7 @@ def setattrdeep(obj, attr, val, getter=getattr, setter=setattr):
         try:
             obj = getter(obj, a)
         except Exception as e:
-            obj = obj[a] = type(obj)()  # assume homogenous nesting
+            obj = obj[a] = type(obj)()  # assume homogeneous nesting
 
     setter(obj, attrs[-1], val)
 
@@ -472,14 +518,16 @@ def getitemdef(o, k, default=None):
     except Exception:
         return default
 
-def ItemColumn(name=None, expr=None, **kwargs):
+class ItemColumn(Column):
     'Column using getitem/setitem with *key*.'
-    return Column(name,
+    def __init__(self, name=None, expr=None, **kwargs):
+        super().__init__(name,
             expr=expr if expr is not None else name,
             getter=lambda col,row: getitemdeep(row, col.expr, None),
             setter=lambda col,row,val: setitemdeep(row, col.expr, val),
             **kwargs)
 
+
 class SubColumnFunc(Column):
     'Column compositor; preprocess row with *subfunc*(row, *expr*) before passing to *origcol*.getValue and *origcol*.setValue.'
     def __init__(self, name='', origcol=None, expr=None, subfunc=getitemdef, **kwargs):
@@ -550,10 +598,6 @@ class ExprColumn(Column):
 
 class SettableColumn(Column):
     'Column using rowid to store and retrieve values internally.'
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        self._store = {}
-
     def putValue(self, row, value):
         self._store[self.sheet.rowid(row)] = value
 
@@ -561,6 +605,9 @@ class SettableColumn(Column):
         return self._store.get(self.sheet.rowid(row), None)
 
 
+SettableColumn.init('_store', dict, copy=True)
+
+
 # synonyms
 ColumnItem = ItemColumn
 ColumnAttr = AttrColumn
