@@ -1,5 +1,6 @@
 import time
-from visidata import vd, date, Sheet, ColumnsSheet
+from visidata import vd, Sheet, ColumnsSheet
+from visidata.type_date import date
 
 
 @Sheet.api
@@ -11,10 +12,12 @@ def customdate(sheet, fmtstr):
                 return super().__new__(cls, *time.strptime(args[0], fmtstr)[:6])
             return super().__new__(cls, *args, **kwargs)
 
-    vd.addType(_customdate, '@', '', formatter=lambda fmt,val: val.strftime(fmt or sheet.options.disp_date_fmt))
     _customdate.__name__ = 'customdate(%s)' % fmtstr
+
+    vd.addType(_customdate, '@', '', formatter=lambda fmt,val: val.strftime(fmt or sheet.options.disp_date_fmt))
+    vd.numericTypes.append(_customdate)
     return _customdate
 
 
-Sheet.addCommand('z@', 'type-customdate', 'cursorCol.type=customdate(input("date format: ", type="fmtstr"))', 'set type of current column to custom date format')
-ColumnsSheet.addCommand('gz@', 'type-customdate-selected', 'onlySelectedRows.type=customdate(input("date format: ", type="fmtstr"))', 'set type of selected columns to date')
+Sheet.addCommand('z@', 'type-customdate', 'fmt=input("date format: ", type="fmtstr"); cursorCol.type=customdate(fmt); cursorCol.fmtstr=fmt', 'set type of current column to custom date format')
+ColumnsSheet.addCommand('gz@', 'type-customdate-selected', 'fmt=input("date format: ", type="fmtstr"); onlySelectedRows.type=customdate(fmt); onlySelectedRows.fmtstr=fmt', 'set type of selected columns to date')
