@@ -94,7 +94,7 @@ class DescribeSheet(ColumnsSheet):
                 for func in [min, max, sum, median]:  # use type
                     d[func.__name__] = self.calcStatistic(d, func, vals)
                 for aggrname in vd.options.describe_aggrs.split():
-                    func = globals()[aggrname]
+                    func = vd.getGlobals()[aggrname]
                     d[func.__name__] = self.calcStatistic(d, func, vals)
 
     def calcStatistic(self, d, func, *args, **kwargs):
