@@ -20,6 +20,9 @@ vd.option('disp_menu_fmt', 'Ctrl+H for help menu', 'right-side menu format strin
 BaseSheet.init('activeMenuItems', list)
 vd.menuRunning = False
 
+def menudraw(*args):
+    return clipdraw(*args, truncator=' ')
+
 
 def Menu(title, *args):
     'Construct menu command or submenu.  *title* is displayed text for this item; *args* is either a single command longname, or recursive Menu elements.'
@@ -113,7 +116,10 @@ vd.menus = [
         Menu('New', 'open-new'),
         Menu('Open file/url', 'open-file'),
         Menu('Rename', 'rename-sheet'),
-        Menu('Guard', 'guard-sheet'),
+        Menu('Guard', 
+            Menu('on', 'guard-sheet'),
+            Menu('off', 'guard-sheet-off')
+        ),
         Menu('Duplicate',
             Menu('selected rows by ref', 'dup-selected'),
             Menu('all rows by ref', 'dup-rows'),
@@ -183,13 +189,14 @@ vd.menus = [
 #            Menu('Visible rows ', 'delete-visible'),
         ),
         Menu('Copy',
-            Menu('current row', 'copy-row'),
             Menu('current cell', 'copy-cell'),
+            Menu('current row', 'copy-row'),
             Menu('selected cells', 'copy-cells'),
+            Menu('selected rows', 'copy-selected'),
             Menu('to system clipboard',
                 Menu('current cell', 'syscopy-cell'),
-                Menu('selected cells', 'syscopy-cells'),
                 Menu('current row', 'syscopy-row'),
+                Menu('selected cells', 'syscopy-cells'),
                 Menu('selected rows', 'syscopy-selected'),
             ),
         ),
@@ -321,8 +328,9 @@ vd.menus = [
                 Menu('one column', 'addcol-new'),
                 Menu('columns', 'addcol-bulk'),
             ),
-            Menu('regex capture', 'addcol-capture'),
-            Menu('regex subst', 'addcol-subst'),
+            Menu('capture by regex', 'addcol-capture'),
+            Menu('split by regex', 'addcol-split'),
+            Menu('subst by regex', 'addcol-subst'),
             Menu('Python expr', 'addcol-expr'),
             Menu('increment', 'addcol-incr'),
             Menu('shell', 'addcol-shell'),
@@ -349,11 +357,13 @@ vd.menus = [
                 Menu('page', 'go-pageup'),
                 Menu('null', 'go-prev-null'),
                 Menu('value', 'go-prev-value'),
+                Menu('selected', 'go-prev-selected'),
             ),
             Menu('next',
                 Menu('page', 'go-pagedown'),
                 Menu('null', 'go-next-null'),
                 Menu('value', 'go-next-value'),
+                Menu('selected', 'go-next-selected'),
             ),
         ),
         Menu('Select',
@@ -384,7 +394,7 @@ vd.menus = [
                 Menu('all columns', 'unselect-cols-regex'),
             ),
         ),
-        Menu('toggle select',
+        Menu('Toggle select',
             Menu('current row', 'stoggle-row'),
             Menu('all rows', 'stoggle-rows'),
             Menu('from top', 'stoggle-before'),
@@ -495,16 +505,16 @@ def drawSubmenu(vd, scr, sheet, y, x, menus, level, disp_menu_boxchars=''):
 
     # draw borders before/under submenus
     if level > 1:
-        clipdraw(scr, y-1, x, tl+ts*(w+2)+tr, colors.color_menu)  # top
+        menudraw(scr, y-1, x, tl+ts*(w+2)+tr, colors.color_menu)  # top
 
-    clipdraw(scr, y+len(menus), x, bl+bs*(w+2)+br, colors.color_menu) #  bottom
+    menudraw(scr, y+len(menus), x, bl+bs*(w+2)+br, colors.color_menu) #  bottom
 
     i = 0
     for j, item in enumerate(menus):
         attr = colors.color_menu
         bindattr = colors.color_keystrokes
 
-        if any(x.obj not in ['BaseSheet', 'TableSheet'] for x, _ in walkmenu(item)):
+        if any(foo.obj not in ['BaseSheet', 'TableSheet'] for foo, _ in walkmenu(item)):
             bindattr = attr = colors.color_menu_spec
 
         if level < len(sheet.activeMenuItems):
@@ -514,7 +524,7 @@ def drawSubmenu(vd, scr, sheet, y, x, menus, level, disp_menu_boxchars=''):
             if level < len(sheet.activeMenuItems):
                 vd.drawSubmenu(scr, sheet, y+i, x+w+4, item.menus, level+1, disp_menu_boxchars=disp_menu_boxchars)
 
-        clipdraw(scr, y+i, x, ls, colors.color_menu)
+        menudraw(scr, y+i, x, ls, colors.color_menu)
 
         title = item.title
         pretitle= ' '
@@ -540,16 +550,17 @@ def drawSubmenu(vd, scr, sheet, y, x, menus, level, disp_menu_boxchars=''):
         # actually display the menu item
         title += ' '*(w-len(pretitle)-len(item.title)-maxbinding+1) # padding
 
-        clipdraw(scr, y+i, x+1, pretitle+title, attr)
+        menudraw(scr, y+i, x+1, pretitle+title, attr)
         if maxbinding:
-            clipdraw(scr, y+i, x+1+w-maxbinding, '  ' + mainbinding, bindattr)
-        clipdraw(scr, y+i, x+2+w, titlenote, attr)
-        clipdraw(scr, y+i, x+3+w, ls, colors.color_menu)
+            menudraw(scr, y+i, x+1+w-maxbinding, '  ' + mainbinding, bindattr)
+        menudraw(scr, y+i, x+2+w, titlenote, attr)
+        menudraw(scr, y+i, x+3+w, ls, colors.color_menu)
 
         vd.onMouse(scr, y+i, x, 1, w+3,
                 BUTTON1_PRESSED=lambda y,x,key,p=sheet.activeMenuItems[:level]+[j]: sheet.pressMenu(*p),
                 BUTTON2_PRESSED=vd.nop,
                 BUTTON3_PRESSED=vd.nop,
+                BUTTON1_CLICKED=lambda y,x,key,p=sheet.activeMenuItems[:level]+[j]: sheet.pressMenu(*p),
                 BUTTON1_RELEASED=vd.nop,
                 BUTTON2_RELEASED=vd.nop,
                 BUTTON3_RELEASED=vd.nop)
@@ -613,15 +624,16 @@ def drawMenu(vd, scr, sheet):
         else:
             attr = colors.color_menu
 
-        clipdraw(scr, 0, x, ' ', attr)
+        menudraw(scr, 0, x, ' ', attr)
         for j, ch in enumerate(item.title):
-            clipdraw(scr, 0, x+j+1, ch, attr | (curses.A_UNDERLINE if ch.isupper() else 0))
-        clipdraw(scr, 0, x+j+2, ' ', attr)
+            menudraw(scr, 0, x+j+1, ch, attr | (curses.A_UNDERLINE if ch.isupper() else 0))
+        menudraw(scr, 0, x+j+2, ' ', attr)
 
         vd.onMouse(scr, 0, x, 1, len(item.title)+2,
                 BUTTON1_PRESSED=lambda y,x,key,i=i,sheet=sheet: sheet.pressMenu(i),
                 BUTTON2_PRESSED=vd.nop,
                 BUTTON3_PRESSED=vd.nop,
+                BUTTON1_CLICKED=lambda y,x,key,i=i,sheet=sheet: sheet.pressMenu(i),
                 BUTTON1_RELEASED=vd.nop,
                 BUTTON2_RELEASED=vd.nop,
                 BUTTON3_RELEASED=vd.nop)
@@ -629,7 +641,7 @@ def drawMenu(vd, scr, sheet):
 
 
     rightdisp = sheet.options.disp_menu_fmt.format(sheet=sheet, vd=vd)
-    clipdraw(scr, 0, x+4, rightdisp, colors.color_menu)
+    menudraw(scr, 0, x+4, rightdisp, colors.color_menu)
 
     if not sheet.activeMenuItems:
         return
@@ -659,30 +671,29 @@ def drawMenu(vd, scr, sheet):
     menuy = 16 # min(menuh, h-len(helplines)-3)
 
     y = menuy
-
-    clipdraw(scr, y, helpx, tl+ts*(helpw-2)+tr, helpattr) # top line
+    menudraw(scr, y, helpx, tl+ts*(helpw-2)+tr, helpattr) # top line
     y += 1
 
     # cmd.helpstr text
     for i, line in enumerate(helplines):
-        clipdraw(scr, y+i, helpx, ls+' '+line+' '*(helpw-len(line)-3)+rs, helpattr)
+        menudraw(scr, y+i, helpx, ls+' '+line+' '*(helpw-len(line)-3)+rs, helpattr)
     y += len(helplines)
 
     if sidelines:
-        clipdraw(scr, y, helpx, ls+' '*(helpw-2)+rs, helpattr)
+        menudraw(scr, y, helpx, ls+' '*(helpw-2)+rs, helpattr)
         for i, line in enumerate(sidelines):
-            clipdraw(scr, y+i+1, helpx, ls+'    '+line+' '*(helpw-len(line)-6)+rs, helpattr)
+            menudraw(scr, y+i+1, helpx, ls+'    '+line+' '*(helpw-len(line)-6)+rs, helpattr)
         y += len(sidelines)+1
 
-    clipdraw(scr, y, helpx, bl+bs*(helpw-2)+br, helpattr)
+    menudraw(scr, y, helpx, bl+bs*(helpw-2)+br, helpattr)
 
     mainbinding = sheet.revbinds.get(cmd.longname, [None])[0]
     if mainbinding:
-        clipdraw(scr, menuy, helpx+2, rsl, helpattr)
+        menudraw(scr, menuy, helpx+2, rsl, helpattr)
         ks = vd.prettykeys(mainbinding or '(unbound)')
-        clipdraw(scr, menuy, helpx+3, ' '+ks+' ', colors.color_menu_active)
-        clipdraw(scr, menuy, helpx+2+len(ks)+3, lsr, helpattr)
-    clipdraw(scr, menuy, helpx+19, ' '+cmd.longname+' ', helpattr)
+        menudraw(scr, menuy, helpx+3, ' '+ks+' ', colors.color_menu_active)
+        menudraw(scr, menuy, helpx+2+len(ks)+3, lsr, helpattr)
+    menudraw(scr, menuy, helpx+19, ' '+cmd.longname+' ', helpattr)
 
 
 @BaseSheet.api
@@ -720,6 +731,7 @@ def runMenu(vd):
     vd.menuRunning = True
     sheet = vd.activeSheet
     vd.setWindows(vd.scrFull)
+    nEscapes = 0
 
     try:
       while True:
@@ -730,21 +742,31 @@ def runMenu(vd):
 
         k = vd.getkeystroke(vd.scrMenu, sheet)
 
+        if not k:
+            continue
+
         currentItem = getMenuItem(sheet)
 
-        if k in ['^C', '^Q', '^[', 'q']:
+        if k == '^[':  # ESC
+            nEscapes += 1  #1470
+            if nEscapes > 1:
+                return
+            continue
+        else:
+            nEscapes = 0
+
+        if k in ['^C', '^Q', 'q']:
             return
 
         elif k in ['KEY_MOUSE']:
-            keystroke, y, x, winname, winscr = vd.parseMouse(menu=vd.scrMenu, top=vd.winTop, bot=vd.winBottom)
-            if winname != 'menu':  # clicking off the menu is an escape
-                return
-            f = vd.getMouse(winscr, x, y, keystroke)
-            if f:
-                if f(y, x, keystroke):
-                    break
-            else:
-                return
+            for keystroke, y, x, winname, winscr in vd.parseMouse(menu=vd.scrMenu, top=vd.winTop, bot=vd.winBottom):
+                if winname == 'menu':
+                    f = vd.getMouse(winscr, x, y, keystroke)
+                    if f:
+                        if f(y, x, keystroke):
+                            break
+                    else:
+                        return  # clicking off the menu is an escape
 
         elif k in ['KEY_RIGHT', 'l']:
             if currentItem.menus and sheet.activeMenuItems[1] != 0:  # not first item
@@ -770,6 +792,12 @@ def runMenu(vd):
             else:
                 break
 
+        elif k in main_menu.keys():
+            sheet.pressMenu(main_menu[k])
+
+        else:
+            vd.warning(f'unknown keystroke {k}')
+
         sheet.checkMenu()
 
     finally:
@@ -780,6 +808,7 @@ def runMenu(vd):
     vd.draw_all()
     sheet.execCommand(currentItem.longname)
 
+main_menu = {'f': 'File', 'e': 'Edit', 'v': 'View', 'c': 'Column', 'r': 'Row', 'd': 'Data', 'p': 'Plot', 's': 'System', 'h': 'Help'}
 
 BaseSheet.addCommand('^[f', 'menu-file', 'pressMenu("File")', '')
 BaseSheet.addCommand('^[e', 'menu-edit', 'pressMenu("Edit")', '')
