@@ -5,14 +5,14 @@ import io
 import codecs
 import pathlib
 from urllib.parse import urlparse, urlunparse
-from functools import wraps
+from functools import wraps, lru_cache
 
 from visidata import *
 
 vd.option('encoding', 'utf-8', 'encoding passed to codecs.open', replay=True)
 vd.option('encoding_errors', 'surrogateescape', 'encoding_errors passed to codecs.open', replay=True)
 
-@functools.lru_cache()
+@lru_cache()
 def vstat(path, force=False):
     try:
         return os.stat(path)
@@ -74,11 +74,9 @@ class FileProgress:
         # track Progress on original fp
         self.fp_orig_read = self.fp.read
         self.fp_orig_close = self.fp.close
-        # These two lines result in bug #1159, a corrupted save of corruption formats
-        # for now we are reverting by commenting out, and opened #1175 to investigate
-        # Progress bars for compression formats might not work in the meanwhile
-        #self.fp.read = self.read
-        #self.fp.close = self.close
+
+        self.fp.read = self.read
+        self.fp.close = self.close
 
         if self.prog:
             self.prog.__enter__()
@@ -131,7 +129,7 @@ class Path(os.PathLike):
         self.filesize = filesize
         self.rfile = None
 
-    @functools.lru_cache()
+    @lru_cache()
     def stat(self, force=False):
         return self._path.stat()
 
@@ -151,6 +149,8 @@ class Path(os.PathLike):
         self.ext = self.suffix[1:]
         if self.suffix:  #1450  don't make this a oneliner; [:-0] doesn't work
             self.name = self._path.name[:-len(self.suffix)]
+        elif self._given == '.':  #1768
+            self.name = '.'
         else:
             self.name = self._path.name
 
@@ -245,22 +245,29 @@ class Path(os.PathLike):
             return FileProgress(self, fp=BytesIOWrapper(self.fptext), **kwargs)
 
         path = self
-        binmode = 'wb' if 'w' in kwargs.get('mode', '') else 'rb'
+
         if self.compression == 'gz':
             import gzip
-            return gzip.open(FileProgress(path, fp=open(path, mode=binmode), **kwargs), *args, **kwargs)
+            zopen = gzip.open
         elif self.compression == 'bz2':
             import bz2
-            return bz2.open(FileProgress(path, fp=open(path, mode=binmode), **kwargs), *args, **kwargs)
+            zopen = bz2.open
         elif self.compression in ['xz', 'lzma']:
             import lzma
-            return lzma.open(FileProgress(path, fp=open(path, mode=binmode), **kwargs), *args, **kwargs)
+            zopen = lzma.open
         elif self.compression == 'zst':
             import zstandard
-            return zstandard.open(FileProgress(path, fp=open(path, mode=binmode), **kwargs), *args, **kwargs)
+            zopen = zstandard.open
         else:
             return FileProgress(path, fp=self._path.open(*args, **kwargs), **kwargs)
 
+        if 'w' in kwargs.get('mode', ''):
+            #1159 FileProgress on the outside to close properly when writing
+            return FileProgress(path, fp=zopen(path, **kwargs), **kwargs)
+
+        #1255 FileProgress on the inside to track uncompressed bytes when reading
+        return zopen(FileProgress(path, fp=open(path, mode='rb'), **kwargs), **kwargs)
+
     def __iter__(self):
         with Progress(total=filesize(self)) as prog:
             with self.open_text(encoding=vd.options.encoding) as fd:
@@ -289,7 +296,7 @@ class Path(os.PathLike):
         return str(self._path)
 
     @wraps(pathlib.Path.stat)
-    @functools.lru_cache()
+    @lru_cache()
     def stat(self, force=False):
         'Return Path.stat() if relevant.'
         try:
@@ -315,10 +322,10 @@ class Path(os.PathLike):
         'Return a sibling Path with *name* as a filename in the same directory.'
         if self.is_url():
             urlparts = list(urlparse(self.given))
-            urlparts[2] = '/'.join(Path(urlparts[2])._parts[1:-1] + [name])
+            urlparts[2] = '/'.join(list(Path(urlparts[2]).parts[1:-1]) + [name])
             return Path(urlunparse(urlparts))
         else:
-            return Path(self._from_parsed_parts(self._drv, self._root, self._parts[:-1] + [name]))
+            return Path(self._from_parsed_parts(self._drv, self._root, list(self.parts[:-1]) + [name]))
 
 
 class RepeatFile:
@@ -348,6 +355,9 @@ class RepeatFile:
                 break  # end of file
         return r
 
+    def write(self, s):
+        return self.iter_lines.write(s)
+
     def tell(self):
         '''Tells the current position as an opaque line marker.'''
         return self.iter.nextIndex
